pyparsing.pyparsing.ParseException

Package pyparsing :: Module pyparsing :: Class ParseException |
[frames | no frames]

## Type ParseException

       object --+
                |
    BaseException --+
                    |
            Exception --+
                        |
       ParseBaseException --+
                            |
                           ParseException

exception thrown when parse expressions don't match class; supported attributes by name are:

- lineno - returns the line number of the exception text
- col - returns the column number of the exception text
- line - returns the line containing the exception text

Method Summary
Inherited from `ParseBaseException`: `__init__`, `__getattr__`, `__repr__`, `__str__`, `markInputline` Inherited from `Exception`: `__new__` Inherited from `BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Class Variable Summary
Inherited from `ParseBaseException`: `__slots__`, `loc`, `msg`, `parserElement`, `pstr` Inherited from `BaseException`: `args`, `message`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net